Stan Math Library: stan/math/prim/mat/fun/eigenvalues_sym.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

eigenvalues_sym.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_EIGENVALUES_SYM_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_EIGENVALUES_SYM_HPP
3
4 #include <stan/math/prim/arr/err/check_nonzero_size.hpp>
5 #include <stan/math/prim/mat/err/check_symmetric.hpp>
6 #include <stan/math/prim/mat/fun/Eigen.hpp>
7
8 namespace stan {
9 namespace math {
10
20 template <typename T>
21 Eigen::Matrix<T, Eigen::Dynamic, 1>
22 eigenvalues_sym(const Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>& m) {
23 stan::math::check_nonzero_size("eigenvalues_sym", "m", m);
24 stan::math::check_symmetric("eigenvalues_sym", "m", m);
25
26 Eigen::SelfAdjointEigenSolver
27 <Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic> >
28 solver(m, Eigen::EigenvaluesOnly);
29 return solver.eigenvalues();
30 }
31
32 }
33 }
34 #endif
stan
Definition: log_sum_exp.hpp:8
check_symmetric.hpp
stan::math::check_nonzero_size
bool check_nonzero_size(const char *function, const char *name, const T_y &y)
Return true if the specified matrix/vector is of non-zero size.
Definition: check_nonzero_size.hpp:30
Eigen.hpp
stan::math::eigenvalues_sym
Eigen::Matrix< T, Eigen::Dynamic, 1 > eigenvalues_sym(const Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &m)
Return the eigenvalues of the specified symmetric matrix in descending order of magnitude.
Definition: eigenvalues_sym.hpp:22
stan::math::check_symmetric
bool check_symmetric(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is symmetric.
Definition: check_symmetric.hpp:37
check_nonzero_size.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.